Learn R Programming

ggbreak (version 0.1.5)

scale_x_cut: scale_x_cut

Description

scale_x_cut

scale_y_cut

Usage

scale_x_cut(breaks, which = NULL, scales = NULL, expand = FALSE, space = 0.1)

scale_y_cut(breaks, which = NULL, scales = NULL, expand = FALSE, space = 0.1)

Value

gg object

Arguments

breaks

a numeric or numeric vector, the points to be divided

which

integer, the position of subplots to scales, started from left to right or top to bottom.

scales

numeric, relative width or height of subplots.

expand

default is FALSE, logical a vector of range expansion constants used to add some padding around the data to ensure that they are placed some distance away from the axes. Use the convenience function expansion() of ggplot2 to generate the values for the expand argument. The defaults are to expand the scale by 5% on each side for continuous variables. If it is logical, the TRUE means the default of ggplot2 (foregoing statement), and FALSE means no expand for the plot.

space

the blank space among the subplots after cut, default is 0.1 (cm).

Examples

Run this code
library(ggplot2)
library(ggbreak)
set.seed(2019-01-19)
d <- data.frame(
     x = 1:20,
     y = c(rnorm(5) + 4, rnorm(5) + 20, rnorm(5) + 5, rnorm(5) + 22)
 )
p <- ggplot(d, aes(x, y)) + geom_col()
p + scale_y_cut(breaks=c(7, 18), which=c(1, 3), scales=c(3, 0.5))

Run the code above in your browser using DataLab